@@ -14,7 +14,7 @@ Grid2Polygons <- function (grd, zcol=1, level=FALSE, at, cuts=20,
   FindPolyNodes <- function (s) {
 
     # Remove duplicate segments
-    id <- paste(apply(s, 1, min), apply(s, 1, max), sep='')
+    id <- paste(apply(s, 1, min), apply(s, 1, max), sep="")
     duplicates <- unique(id[duplicated(id)])
     s <- s[!id %in% duplicates, ]
 
@@ -23,7 +23,7 @@ Grid2Polygons <- function (grd, zcol=1, level=FALSE, at, cuts=20,
 
     # Call C program to define polygon rings
     out <- matrix(.C("define_polygons", as.integer(s[, 1]), as.integer(s[, 2]),
-                     as.integer(m), "ans"=integer(m * 2))$ans, nrow=m, ncol=2)
+                     as.integer(m), "ans"=integer(m * 2L))$ans, nrow=m, ncol=2L)
 
     # Place returned array into list object
     poly.nodes <- lapply(unique(out[, 2]), function(i) out[out[, 2] == i, 1])
@@ -31,14 +31,12 @@ Grid2Polygons <- function (grd, zcol=1, level=FALSE, at, cuts=20,
     # Close polygon by joining the first point to the last point
     poly.nodes <- lapply(poly.nodes, function(i) c(i, i[1]))
 
-    poly.nodes
+    return(poly.nodes)
   }
 
 
   # Main program
 
-  require(sp)
-
   # Check arguments
   if (!inherits(grd, "SpatialGridDataFrame"))
     stop("Grid object not of class SpatialGridDataFrame")
@@ -46,8 +44,8 @@ Grid2Polygons <- function (grd, zcol=1, level=FALSE, at, cuts=20,
     stop("Column name not in attribute table")
   if (is.numeric(zcol) && zcol > ncol(slot(grd, "data")))
     stop("Column number outside bounds of attribute table")
-  if (!is.null(ply) && !inherits(ply, c("SpatialPolygons", 
-                                        "SpatialPolygonsDataFrame", 
+  if (!is.null(ply) && !inherits(ply, c("SpatialPolygons",
+                                        "SpatialPolygonsDataFrame",
                                         "gpc.poly")))
     stop("Polygon class is incorrect")
 
@@ -60,9 +58,10 @@ Grid2Polygons <- function (grd, zcol=1, level=FALSE, at, cuts=20,
     vertices <- matrix(c(xlim[1], xlim[2], xlim[2], xlim[1], xlim[1],
                          ylim[1], ylim[1], ylim[2], ylim[2], ylim[1]),
                          nrow=5, ncol=2)
-    ply.box <- SpatialPolygons(list(Polygons(list(Polygon(vertices, hole=FALSE)), 1)))
+    ply.box <- SpatialPolygons(list(Polygons(list(Polygon(vertices,
+                                                          hole=FALSE)), 1)))
     proj4string(ply.box) <- CRS(proj4string(grd))
-    grd[[zcol]] <- grd[[zcol]] * sp::overlay(grd, ply.box)
+    grd[[zcol]][is.na(over(grd, ply.box))] <- NA
   }
 
   # Determine break points
@@ -74,7 +73,7 @@ Grid2Polygons <- function (grd, zcol=1, level=FALSE, at, cuts=20,
       else
         at <- seq(zlim[1], zlim[2], length.out=cuts)
     }
-    zc <- at[1:(length(at) - 1)] + diff(at) / 2
+    zc <- at[1:(length(at) - 1L)] + diff(at) / 2
     z <- zc[findInterval(grd[[zcol]], at, rightmost.closed=TRUE)]
   } else {
     z <- grd[[zcol]]
@@ -92,21 +91,21 @@ Grid2Polygons <- function (grd, zcol=1, level=FALSE, at, cuts=20,
   ymax <- ymin + m * dy
   x <- seq(xmin, xmax, by=dx)
   y <- seq(ymin, ymax, by=dy)
-  nnodes <- (m + 1) * (n + 1)
+  nnodes <- (m + 1L) * (n + 1L)
   nelems <- m * n
-  nodes <- 1:nnodes
-  elems <- 1:nelems
-  coords <- cbind(x=rep(x, m + 1), y=rep(rev(y), each=n + 1))
-  n1 <- c(sapply(1:m, function(i) seq(1, n) + (i - 1) * (n + 1)))
-  n2 <- n1 + 1
-  n4 <- c(sapply(1:m, function(i) seq(1, n) + i * (n + 1)))
-  n3 <- n4 + 1
+  nodes <- 1L:nnodes
+  elems <- 1L:nelems
+  coords <- cbind(x=rep(x, m + 1L), y=rep(rev(y), each=n + 1L))
+  n1 <- c(sapply(1L:m, function(i) seq(1L, n) + (i - 1L) * (n + 1L)))
+  n2 <- n1 + 1L
+  n4 <- c(sapply(1L:m, function(i) seq(1L, n) + i * (n + 1L)))
+  n3 <- n4 + 1L
   elem.nodes <- cbind(n1, n2, n3, n4)
 
   # Define segments in each element
-  nsegs <- nelems * 4
+  nsegs <- nelems * 4L
   segs <- matrix(data=NA, nrow=nsegs, ncol=4,
-                 dimnames=list(1:nsegs, c("elem", "a", "b", "z")))
+                 dimnames=list(1L:nsegs, c("elem", "a", "b", "z")))
   segs[, 1] <- rep(1:nelems, each=4)
   segs[, 2] <- c(t(elem.nodes))
   segs[, 3] <- c(t(elem.nodes[, c(2, 3, 4, 1)]))
@@ -125,9 +124,9 @@ Grid2Polygons <- function (grd, zcol=1, level=FALSE, at, cuts=20,
   poly <- lapply(poly.nodes, fun)
 
   # Build list of Polygons objects
-  ids <- make.names(1:length(poly), unique=TRUE)
+  ids <- make.names(1L:length(poly), unique=TRUE)
   fun <- function(i) Polygons(poly[[i]], ID=ids[i])
-  polys <- lapply(1:length(poly), fun)
+  polys <- lapply(1L:length(poly), fun)
 
   # Convert to SpatialPolygons object, add datum and projection
   sp.polys <- SpatialPolygons(polys, proj4string=CRS(proj4string(grd)))
@@ -135,7 +134,7 @@ Grid2Polygons <- function (grd, zcol=1, level=FALSE, at, cuts=20,
   # Convert to SpatialPolygonsDataFrame object, add data frame of levels
   d <- data.frame(z=levs, row.names=row.names(sp.polys))
   sp.polys.df <- SpatialPolygonsDataFrame(sp.polys, data=d, match.ID=TRUE)
-  
+
   # Crop SpatialPolygonsDataFrame object using polygon argument
   if (!is.null(ply)) {
     if (!inherits(ply, "gpc.poly"))
@@ -149,18 +148,18 @@ Grid2Polygons <- function (grd, zcol=1, level=FALSE, at, cuts=20,
       is.included[i] <- length(p@pts) > 0
       if (is.included[i]) {
         s.plys <- as(p, "SpatialPolygons")
-        l.plys <- lapply(slot(s.plys, "polygons"), 
+        l.plys <- lapply(slot(s.plys, "polygons"),
                          function(j) {slot(j, "ID") <- ids[i]; j})
         p2 <- c(p2, l.plys)
       }
     }
     if (length(p2) > 0) {
       p2 <- SpatialPolygons(p2, proj4string=CRS(proj4string(grd)))
-      d <- data.frame(z=sp.polys.df[[zcol]][is.included], 
+      d <- data.frame(z=sp.polys.df[[zcol]][is.included],
                       row.names=ids[is.included])
       sp.polys.df <- SpatialPolygonsDataFrame(p2, data=d)
     }
   }
 
-  sp.polys.df
+  return(sp.polys.df)
 }
